Eyes Core Python SDK
====================

Applitools Eyes Core SDK For Python


Installation
------------

Install the eyes-core SDK.

::

    pip install eyes-core

Usage
-----

It could be used to create own Applitools SDK
